@@ -36,7 +36,7 @@ from nowcasting_dataset.dataset.xr_utils import (
     convert_coordinates_to_indexes_for_list_datasets,
     join_list_dataset_to_batch_dataset,
 )
-from nowcasting_dataset.geospatial import lat_lon_to_osgb
+from nowcasting_dataset.geospatial import lat_lon_to_osgb, osgb_to_geostationary
 
 
 def make_fake_batch(configuration: Configuration, temporally_align_examples: bool = False) -> dict:
@@ -578,6 +578,14 @@ def create_image_array(
         dims = ("time", "y_geostationary", "x_geostationary", "channels")
         coords["y_osgb"] = (("y_geostationary", "x_geostationary"), y_osgb)
         coords["x_osgb"] = (("y_geostationary", "x_geostationary"), x_osgb)
+
+        # Compute fake geostationary coords by converting the OSGB coords to geostationary,
+        # and then selecting one row or one column from the converted coords (because the
+        # geostationary coords are each 1D). Remember that `x_osgb` and `y_osgb` are
+        # both 2D, of shape (y, x).
+        x_geostationary, y_geostationary = osgb_to_geostationary(x=x_osgb, y=y_osgb)
+        coords["y_geostationary"] = y_geostationary[:, 0]
+        coords["x_geostationary"] = x_geostationary[0, :]
     else:
         raise ValueError(
             f"nwp_or_satellite must be either 'nwp' or 'satellite', not '{nwp_or_satellite}'"
